deco3 documentation
===================

.. _readme:
.. include:: README.rst

Contents
========

.. toctree::
   :maxdepth: 2

   CHANGES.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
